@@ -2,5 +2,7 @@ from ._filter import *
 from .aggregate import *
 from .apply import *
 from .general import *
+from .indices import *
+from .load import *
 from .merge import *
 from .reduce import *
