@@ -6,8 +6,11 @@ import dask_geopandas
 import geopandas as gpd
 import numpy as np
 import xarray as xr
-import xgboost as xgb
+from xgboost.core import Booster
 
+from openeo_processes_dask.process_implementations.cubes.experimental import (
+    load_vector_cube,
+)
 from openeo_processes_dask.process_implementations.data_model import (
     RasterCube,
     VectorCube,
@@ -24,7 +27,9 @@ def fit_regr_random_forest(
     predictors_vars: Optional[list[str]] = None,
     target_var: str = None,
     **kwargs,
-):  # -> RegressionModel
+) -> Booster:
+    import xgboost as xgb
+
     params = {
         "learning_rate": 1,
         "max_depth": 5,
@@ -43,6 +48,9 @@ def fit_regr_random_forest(
             predictors.to_dask_dataframe().reset_index().repartition(npartitions=1)
         )
 
+    if isinstance(predictors, dask.dataframe.DataFrame):
+        data_ddf = predictors
+
     if not isinstance(predictors, dask.dataframe.DataFrame):
         raise Exception("[!] No compatible vector input data has been provided.")
 
@@ -51,63 +59,38 @@ def fit_regr_random_forest(
     else:
         X = data_ddf
 
+    # This is a workaround for the openeo-python-client current returning inline geojson for this process
+    if isinstance(target, str):
+        target = load_vector_cube(filename=target)
+
     y = target.drop(target.columns.difference([target_var]), axis=1)
 
     client = dask.distributed.default_client()
     dtrain = xgb.dask.DaskDMatrix(client, X, y)
     output = xgb.dask.train(client, params, dtrain, num_boost_round=1)
 
-    return output
+    return output["booster"]
 
 
 def predict_random_forest(
     data: RasterCube,
-    dimension: str,
-    model: xgb.Booster,
+    model: Booster,
+    axis: int = -1,
 ) -> RasterCube:
+    import xgboost as xgb
 
-    # Detect whether all features that the model was trained with are present in this data.
-    model_features = np.array(model.feature_names, dtype=object)
-    data_features = data.get_index(dimension).values
-    missing_features = np.setdiff1d(model_features, data_features)
-    if missing_features.size > 0:
+    n_features = len(model.feature_names)
+    if n_features != data.shape[axis]:
         raise Exception(
-            f"Provided predictors are missing the following features: {missing_features.tolist()}"
+            f"Number of predictors does not match number of features that were trained with."
         )
-
-    # Drop any feature columns that the original model wasn't trained on
-    idx_to_drop = np.setdiff1d(data_features, model_features)
-    data = data.drop_sel({dimension: idx_to_drop})
-
-    # Stack xarray to produce correct shape for xgb.dask.inplace_predict
-    non_feature_dims = set(data.dims)
-    non_feature_dims.remove(dimension)
-
-    X = dask.array.reshape(data.data, (len(model_features), -1)).transpose()
+    # move feature axis to first position and flatten other dimensions
+    X = np.moveaxis(data, axis, 0).reshape((n_features, -1)).transpose()
 
     # Run prediction
     client = dask.distributed.default_client()
     preds_flat = xgb.dask.inplace_predict(client, model, X)
 
-    # Construct the output rastercube
-    output_coords = {
-        coord_name: data.coords[coord_name] for coord_name in non_feature_dims
-    }
-
-    # Output shape needs to be (1, data.x, data.y)
-    output_shape = tuple([1] + [len(data[coord]) for coord in output_coords])
-    output_array = dask.array.reshape(preds_flat, output_shape)
-
-    # We call this coord "bands" because the save_result logic expects it to be "bands"
-    output_coords["bands"] = np.array(["result"])
-
-    preds_xr = xr.DataArray(
-        data=output_array,
-        coords=output_coords,
-        dims=["bands"] + [dim for dim in output_coords.keys() if not dim == "bands"],
-        attrs=data.attrs,
-    )
-
-    preds_xr = preds_xr.rio.write_crs(data.rio.crs)
-
-    return preds_xr
+    output_shape = data.shape[0:axis] + data.shape[axis + 1 :]
+    preds = preds_flat.reshape(output_shape)
+    return preds
